declare class BaseError extends Error {
    constructor(message: string);
}
/**
 * Thrown on configuration errors, e.g bad event modes
 */
export declare class ConfigError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when an event is emitted without either passing the tag to `client.emit` or providing a `tag_prefix`.
 */
export declare class MissingTagError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when a client/server receives an unexpected/invalid message
 */
export declare class UnexpectedMessageError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when a client waiting for an acknowledgement times out
 */
export declare class AckTimeoutError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when a client tries to emit an invalid data format, e.g string as timestamp, string event, etc.
 */
export declare class DataTypeError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when a socket times out, but in a weird state.
 */
export declare class SocketTimeoutError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when a client tries to write to a socket, but the socket is not writable
 */
export declare class SocketNotWritableError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when an event is dropped from the queue for any reason
 */
export declare class DroppedError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when an event is dropped as a result of clearing out the queue on shutdown
 *
 * Extends DroppedError since the message was dropped from the queue
 */
export declare class QueueShutdownError extends DroppedError {
    constructor(message: string);
}
/**
 * Thrown into the ack queue on shutdown, terminating all promises waiting for an ack
 */
export declare class AckShutdownError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when the EventRetrier is shut down
 */
export declare class RetryShutdownError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when authentication fails on either the client or the server
 */
export declare class AuthError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when the shared key doesn't match
 *
 * Extends AuthError, since the key was incorrect
 */
export declare class SharedKeyMismatchError extends AuthError {
    constructor(message: string);
}
/**
 * Thrown when a message could not be decoded properly
 */
export declare class DecodeError extends BaseError {
    constructor(message: string);
}
/**
 * Thrown when trying to call `connect()` on a fatal socket
 */
export declare class FatalSocketError extends BaseError {
    constructor(message: string);
}
export {};
