"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Queue = void 0;
const error_1 = require("../error");
/**
 * Exposes a send queue for various event modes.
 */
class Queue {
    /**
     * Drops the item at the front of the queue
     *
     * Handles rejecting the promises, etc
     * @returns void
     */
    dropEntry() {
        const entryData = this.pop();
        if (entryData === null) {
            return;
        }
        else {
            entryData.deferred.reject(new error_1.DroppedError("Message was dropped due to limits"));
        }
    }
    /**
     * Clears out the queue
     */
    clear() {
        let entryData;
        while ((entryData = this.pop()) !== null) {
            entryData.deferred.reject(new error_1.QueueShutdownError("Message dropped due to queue shutdown"));
        }
    }
}
exports.Queue = Queue;
//# sourceMappingURL=queue.js.map